Getting Started
========================================================================================

These pages will help you install and learn the basics of using TAPE. If you encounter any issues
we encourage you to open an issue on the 
`TAPE github repository <https://github.com/lincc-frameworks/tape/issues>`_.

.. toctree::

    Installing TAPE <gettingstarted/installation>
    Quickstart Guide <gettingstarted/quickstart>